summaryrefslogtreecommitdiffhomepage
path: root/wgengine/magicsock/debugknobs.go
diff options
context:
space:
mode:
Diffstat (limited to 'wgengine/magicsock/debugknobs.go')
-rw-r--r--wgengine/magicsock/debugknobs.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/wgengine/magicsock/debugknobs.go b/wgengine/magicsock/debugknobs.go
index 824c677f6..fc0f3ded4 100644
--- a/wgengine/magicsock/debugknobs.go
+++ b/wgengine/magicsock/debugknobs.go
@@ -12,9 +12,9 @@ import (
// Various debugging and experimental tweakables, set by environment
// variable.
var (
// debugDisco prints verbose logs of active discovery events as
// they happen.
- debugDisco = envknob.RegisterBool("TS_DEBUG_DISCO")
+ debugDiscoEnv = envknob.RegisterBool("TS_DEBUG_DISCO")
// debugPeerMap prints verbose logs of changes to the peermap.
debugPeerMap = envknob.RegisterBool("TS_DEBUG_MAGICSOCK_PEERMAP")
// debugOmitLocalAddresses removes all local interface addresses
@@ -12,9 +12,9 @@ import (
// variable.
var (
- // debugDisco prints verbose logs of active discovery events as
+ // debugDiscoEnv prints verbose logs of active discovery events as
// they happen.